==> ucscsdk-0.9.0.2.tar.gz: ucscsdk-0.9.0.2/ucscsdk/mometa/bios/BiosVfMaximumMemoryBelow4GB.py <==
"""This module contains the general information for BiosVfMaximumMemoryBelow4GB ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class BiosVfMaximumMemoryBelow4GBConsts():
    SUPPORTED_BY_DEFAULT_NO = "no"
    SUPPORTED_BY_DEFAULT_YES = "yes"
    VP_MAXIMUM_MEMORY_BELOW4_GB_DISABLED = "disabled"
    VP_MAXIMUM_MEMORY_BELOW4_GB_ENABLED = "enabled"
    VP_MAXIMUM_MEMORY_BELOW4_GB_PLATFORM_DEFAULT = "platform-default"
    VP_MAXIMUM_MEMORY_BELOW4_GB_PLATFORM_RECOMMENDED = "platform-recommended"


class BiosVfMaximumMemoryBelow4GB(ManagedObject):
    """This is BiosVfMaximumMemoryBelow4GB class."""

    consts = BiosVfMaximumMemoryBelow4GBConsts()
    naming_props = set([])

    mo_meta = MoMeta("BiosVfMaximumMemoryBelow4GB", "biosVfMaximumMemoryBelow4GB", "Maximum-memory-below-4GB", VersionMeta.Version111a, "InputOutput", 0x1f, [], ["read-only"], [u'biosVProfile'], [], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "supported_by_default": MoPropertyMeta("supported_by_default", "supportedByDefault", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "yes"], []), 
        "vp_maximum_memory_below4_gb": MoPropertyMeta("vp_maximum_memory_below4_gb", "vpMaximumMemoryBelow4GB", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["disabled", "enabled", "platform-default", "platform-recommended"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "rn": "rn", 
        "status": "status", 
        "supportedByDefault": "supported_by_default", 
        "vpMaximumMemoryBelow4GB": "vp_maximum_memory_below4_gb", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.status = None
        self.supported_by_default = None
        self.vp_maximum_memory_below4_gb = None

        ManagedObject.__init__(self, "BiosVfMaximumMemoryBelow4GB", parent_mo_or_dn, **kwargs)

==> ucscsdk-0.9.0.10.tar.gz: ucscsdk-0.9.0.10/ucscsdk/mometa/bios/BiosVfMaximumMemoryBelow4GB.py <==
"""This module contains the general information for BiosVfMaximumMemoryBelow4GB ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class BiosVfMaximumMemoryBelow4GBConsts():
    SUPPORTED_BY_DEFAULT_NO = "no"
    SUPPORTED_BY_DEFAULT_YES = "yes"
    VP_MAXIMUM_MEMORY_BELOW4_GB_DISABLED = "disabled"
    VP_MAXIMUM_MEMORY_BELOW4_GB_ENABLED = "enabled"
    VP_MAXIMUM_MEMORY_BELOW4_GB_PLATFORM_DEFAULT = "platform-default"
    VP_MAXIMUM_MEMORY_BELOW4_GB_PLATFORM_RECOMMENDED = "platform-recommended"


class BiosVfMaximumMemoryBelow4GB(ManagedObject):
    """This is BiosVfMaximumMemoryBelow4GB class."""

    consts = BiosVfMaximumMemoryBelow4GBConsts()
    naming_props = set([])

    mo_meta = MoMeta("BiosVfMaximumMemoryBelow4GB", "biosVfMaximumMemoryBelow4GB", "Maximum-memory-below-4GB", VersionMeta.Version111a, "InputOutput", 0x1f, [], ["read-only"], ['biosVProfile'], [], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "supported_by_default": MoPropertyMeta("supported_by_default", "supportedByDefault", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "yes"], []), 
        "vp_maximum_memory_below4_gb": MoPropertyMeta("vp_maximum_memory_below4_gb", "vpMaximumMemoryBelow4GB", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["disabled", "enabled", "platform-default", "platform-recommended"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "rn": "rn", 
        "status": "status", 
        "supportedByDefault": "supported_by_default", 
        "vpMaximumMemoryBelow4GB": "vp_maximum_memory_below4_gb", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.status = None
        self.supported_by_default = None
        self.vp_maximum_memory_below4_gb = None

        ManagedObject.__init__(self, "BiosVfMaximumMemoryBelow4GB", parent_mo_or_dn, **kwargs)
